==> slang_retail_assistant-8.7.0.tar.gz: lib/src/slang_retail_conva_trigger_view.dart <==
part of slang_retail_assistant;

class SlangConvaTriggerView extends StatefulWidget {
  final String imageUrl;
  final RetailAssistantOnSearchListener? onSearch;

  const SlangConvaTriggerView({
    Key? key,
    this.imageUrl = 'default_image_url',
    this.onSearch,
  }) : super(key: key);

  @override
  _SlangConvaTriggerViewState createState() => _SlangConvaTriggerViewState();
}

class _SlangConvaTriggerViewState extends State<SlangConvaTriggerView> {
  @override
  void initState() {
    super.initState();
  }

  void handleTap() {
    SlangRetailAssistant.setOnSearchListener((searchInfo, searchUserJourney) {
      widget.onSearch!(searchInfo, searchUserJourney);
    });
  }

  @override
  Widget build(BuildContext context) {
    const String viewType = 'slangconvatriggerview';

    return PlatformViewLink(
      viewType: viewType,
      surfaceFactory:
          (BuildContext context, PlatformViewController controller) {
        return AndroidViewSurface(
          controller: controller as AndroidViewController,
          gestureRecognizers: const <Factory<OneSequenceGestureRecognizer>>{},
          hitTestBehavior: PlatformViewHitTestBehavior.opaque,
        );
      },
      onCreatePlatformView: (PlatformViewCreationParams params) {
        return PlatformViewsService.initSurfaceAndroidView(
          id: params.id,
          viewType: viewType,
          layoutDirection: TextDirection.ltr,
          creationParams: <String, dynamic>{
            'imageUrl':
                widget.imageUrl, // Pass the image URL as a creation parameter
          },
          creationParamsCodec: StandardMessageCodec(),
        )..addOnPlatformViewCreatedListener((int id) {
            // Invoke handleTap when the platform view is created
            if (widget.onSearch != null) {
              handleTap();
            }
          });
      },
    );
  }
}

==> slang_retail_assistant-8.9.5.tar.gz: lib/src/slang_retail_conva_trigger_view.dart <==
part of slang_retail_assistant;

class SlangConvaTriggerView extends StatefulWidget {
  final String imageUrl;
  final String imageAsset;
  final RetailAssistantOnSearchListener? onSearch;

  const SlangConvaTriggerView(
      {Key? key,
      this.imageUrl = 'default_image_url',
      this.imageAsset = 'default_image_asset',
      this.onSearch})
      : super(key: key);

  @override
  _SlangConvaTriggerViewState createState() => _SlangConvaTriggerViewState();
}

class _SlangConvaTriggerViewState extends State<SlangConvaTriggerView> {
  @override
  void initState() {
    super.initState();
  }

  void handleTap() {
    SlangRetailAssistant.setOnSearchListener((searchInfo, searchUserJourney) {
      widget.onSearch!(searchInfo, searchUserJourney);
    });
  }

  @override
  Widget build(BuildContext context) {
    const String viewType = 'slangconvatriggerview';

    return PlatformViewLink(
      viewType: viewType,
      surfaceFactory:
          (BuildContext context, PlatformViewController controller) {
        return AndroidViewSurface(
          controller: controller as AndroidViewController,
          gestureRecognizers: const <Factory<OneSequenceGestureRecognizer>>{},
          hitTestBehavior: PlatformViewHitTestBehavior.opaque,
        );
      },
      onCreatePlatformView: (PlatformViewCreationParams params) {
        return PlatformViewsService.initSurfaceAndroidView(
          id: params.id,
          viewType: viewType,
          layoutDirection: TextDirection.ltr,
          creationParams: <String, dynamic>{
            'imageUrl': widget.imageUrl,
            'imageAsset':
                widget.imageAsset // Pass the image URL as a creation parameter
          },
          creationParamsCodec: StandardMessageCodec(),
        )..addOnPlatformViewCreatedListener((int id) {
            // Invoke handleTap when the platform view is created
            if (widget.onSearch != null) {
              handleTap();
            }
          });
      },
    );
  }
}
